#include "raylib.h"
#include "snake.h"
#include "food.h"
#include "game.h"
#include <stdlib.h>
#include <time.h>
#include <stdio.h>

typedef enum { MENU, PLAYING, GAME_OVER } GameState;

// Modified FlashScreen to work with main loop
void HandleFlashEffect(int *flashFrames, Color *flashColor) {
    if (*flashFrames > 0) {
        BeginDrawing();
        ClearBackground(*flashColor);
        EndDrawing();
        (*flashFrames)--;
    }
}

int main(void) {
    InitWindow(SCREEN_WIDTH, SCREEN_HEIGHT, "Snake Game");
    SetTargetFPS(10);

    // Game state management
    GameState gameState = MENU;
    bool startGame = false;
    int flashFrames = 0;
    Color flashColor = BLANK;

    // Game components
    srand(time(NULL));
    Snake snake;
    Food food;
    InitSnake(&snake);
    SpawnFood(&food);
    int score = 0;

    while (!WindowShouldClose()) {
        // Handle flash effect first
        if (flashFrames > 0) {
            HandleFlashEffect(&flashFrames, &flashColor);
            continue; // Skip other logic during flash
        }

        // State machine
        switch (gameState) {
            case MENU:
                if (IsKeyPressed(KEY_ENTER)) {
                    gameState = PLAYING;
                    flashColor = GREEN;
                    flashFrames = 5; // Short green flash when starting
                }
                break;

            case PLAYING:
                HandleInput(&snake);
                UpdateSnake(&snake);

                // Food collision
                if (snake.segments[0].x == food.position.x && snake.segments[0].y == food.position.y) {
                    score++;
                    snake.length++;
                    SpawnFood(&food);
                    flashColor = YELLOW;
                    flashFrames = 5;
                }

                // Game over check
                if (CheckCollision(&snake)) {
                    gameState = GAME_OVER;
                    flashColor = RED;
                    flashFrames = 10;
                }
                break;

            case GAME_OVER:
                if (IsKeyPressed(KEY_ENTER)) {
                    ResetGame(&snake, &food, &score, &gameState);
                    gameState = PLAYING;
                    flashColor = GREEN;
                    flashFrames = 5;
                }
                break;
        }

        // Drawing
        BeginDrawing();
        ClearBackground(RAYWHITE);

        switch (gameState) {
            case MENU:
                DrawText("SNAKE GAME", SCREEN_WIDTH/2 - 100, SCREEN_HEIGHT/2 - 50, 40, GREEN);
                DrawText("Press ENTER to Start", SCREEN_WIDTH/2 - 120, SCREEN_HEIGHT/2, 20, DARKGRAY);
                break;

            case PLAYING:
                // Draw snake
                for (int i = 0; i < snake.length; i++) {
                    DrawRectangle(snake.segments[i].x * CELL_SIZE, 
                                snake.segments[i].y * CELL_SIZE,
                                CELL_SIZE, CELL_SIZE, GREEN);
                }

                // Draw food
                DrawRectangle(food.position.x * CELL_SIZE, 
                            food.position.y * CELL_SIZE,
                            CELL_SIZE, CELL_SIZE, BLUE);

                // Draw score
                DrawText(TextFormat("Scoreee: %d", score), 10, 10, 20, DARKGRAY);
                break;

            case GAME_OVER:
                DrawText("GAME OVER!", SCREEN_WIDTH/2 - 100, SCREEN_HEIGHT/2 - 40, 40, RED);
                DrawText(TextFormat("Scoreee: %d", score), SCREEN_WIDTH/2 - 60, SCREEN_HEIGHT/2 + 20, 30, DARKGRAY);
                DrawText("Press ENTER to Restaeeert", SCREEN_WIDTH/2 - 140, SCREEN_HEIGHT/2 + 70, 20, GRAY);
                break;
        }

        EndDrawing();
    }

    CloseWindow();
    return 0;
}